@@ -15,6 +15,7 @@
 (require 'geiser-autodoc)
 (require 'geiser-edit)
 (require 'geiser-completion)
+(require 'geiser-syntax)
 (require 'geiser-impl)
 (require 'geiser-eval)
 (require 'geiser-connection)
@@ -65,6 +66,15 @@ implementation name gets appended to it."
    :type 'boolean
    :group 'geiser-repl)
 
+(geiser-custom--defcustom geiser-repl-save-debugging-history-p nil
+  "Whether to skip debugging input in REPL history.
+
+By default, REPL interactions while scheme is in the debugger are
+not added to the REPL command history.  Set this variable to t to
+change that."
+  :type 'boolean
+  :group 'geiser-repl)
+
 (geiser-custom--defcustom geiser-repl-autodoc-p t
   "Whether to enable `geiser-autodoc-mode' in the REPL by default."
   :type 'boolean
@@ -404,7 +414,7 @@ module command as a string")
   (geiser-repl--read-input-ring))
 
 
-;;; Cleaning up on quit
+;;; Cleaning up
 
 (defun geiser-repl--on-quit ()
   (geiser-repl--write-input-ring)
@@ -441,7 +451,8 @@ module command as a string")
         (remove (current-buffer) geiser-repl--closed-repls)))
 
 (defun geiser-repl--input-filter (str)
-  (not (or (geiser-repl--is-debugging)
+  (not (or (and (not geiser-repl-save-debugging-history-p)
+                (geiser-repl--is-debugging))
            (string-match "^\\s *$" str)
            (string-match "^,quit *$" str))))
 
@@ -535,7 +546,8 @@ there's no symbol at point). Otherwise, go to next error in the REPL
 buffer."
   (interactive "p")
   (if (>= (point) (geiser-repl--last-prompt-end))
-      (or (completion-at-point) (lisp-indent-line))
+      (or (completion-at-point)
+          (lisp-indent-line))
     (compilation-next-error n)))
 
 (defun geiser-repl--previous-error (n)
@@ -543,6 +555,14 @@ buffer."
   (interactive "p")
   (compilation-next-error (- n)))
 
+(defun geiser-repl-clear-buffer ()
+  "Delete the output generated by the scheme process."
+  (interactive)
+  (let ((inhibit-read-only t))
+    (delete-region (point-min) (geiser-repl--last-prompt-start))
+    (when (< (point) (geiser-repl--last-prompt-end))
+      (goto-char (geiser-repl--last-prompt-end)))
+    (recenter t)))
 
 (define-derived-mode geiser-repl-mode comint-mode "REPL"
   "Major mode for interacting with an inferior scheme repl process.
@@ -599,9 +619,14 @@ buffer."
   ("Symbol documentation" ("\C-c\C-dd" "\C-c\C-d\C-d")
    geiser-doc-symbol-at-point
    "Documentation for symbol at point" :enable (geiser--symbol-at-point))
+  ("Lookup symbol in manul" ("\C-c\C-di" "\C-c\C-d\C-i")
+   geiser-doc-look-up-manual
+   "Documentation for symbol at point" :enable (geiser--symbol-at-point))
   ("Module documentation" ("\C-c\C-dm" "\C-c\C-d\C-m") geiser-repl--doc-module
    "Documentation for module at point" :enable (geiser--symbol-at-point))
   --
+  ("Clear buffer" "\C-c\M-o" geiser-repl-clear-buffer
+   "Clean up REPL buffer, leaving just a lonely prompt")
   ("Kill Scheme interpreter" "\C-c\C-q" geiser-repl-exit
    :enable (geiser-repl--live-p))
   ("Restart" "\C-c\C-z" switch-to-geiser :enable (not (geiser-repl--live-p)))
